Enum style::stylesheet_set::OriginValidity
[−]
[src]
pub enum OriginValidity {
Valid,
CascadeInvalid,
FullyInvalid,
}The validity of the data in a given cascade origin.
Variants
ValidThe origin is clean, all the data already there is valid, though we may have new sheets at the end.
CascadeInvalidThe cascade data is invalid, but not the invalidation data (which is order-independent), and thus only the cascade data should be inserted.
FullyInvalidEverything needs to be rebuilt.