Enum style::stylesheet_set::SheetRebuildKind
[−]
[src]
pub enum SheetRebuildKind {
Full,
CascadeOnly,
}The type of rebuild that we need to do for a given stylesheet.
Variants
FullA full rebuild, of both cascade data and invalidation data.
CascadeOnlyA partial rebuild, of only the cascade data.
Methods
impl SheetRebuildKind[src]
pub fn should_rebuild_invalidation(&self) -> bool[src]
Whether the stylesheet invalidation data should be rebuilt.